@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2004-2009 Frank Denis. All rights reserved.
+ * Copyright (c) 2004-2010 Frank Denis. All rights reserved.
  * 
  * This crucial part of UCARP is derived from the OpenBSD project.
  * Original copyright follows. 
@@ -155,9 +155,17 @@ int carp_prepare_ad(struct carp_header *ch, struct carp_softc *sc)
 {
     if (sc->sc_init_counter != 0) {
         /* this could also be seconds since unix epoch */
-        sc->sc_counter = random();
+#ifdef HAVE_ARC4RANDOM
+        sc->sc_counter = arc4random();        
+#else
+        sc->sc_counter = random();        
+#endif
         sc->sc_counter <<= 32;
+#ifdef HAVE_ARC4RANDOM        
+        sc->sc_counter += arc4random();
+#else
         sc->sc_counter += random();
+#endif
     } else if (sc->sc_counter == 0xffffffffffffffffULL) {
         sc->sc_counter = 0ULL;
     } else {
@@ -220,7 +228,11 @@ static void carp_send_ad(struct carp_softc *sc)
     ip.ip_hl = (sizeof ip) >> 2;
     ip.ip_tos = IPTOS_LOWDELAY;
     ip.ip_len = htons(ip_len);
+#ifdef HAVE_ARC4RANDOM
+    ip.ip_id = htons(arc4random() & 0xffff);
+#else
     ip.ip_id = htons(random() & 0xffff);
+#endif
     ip.ip_off = htons(IP_DF);
     ip.ip_ttl = CARP_DFLTTL;
     ip.ip_p = IPPROTO_CARP;
@@ -693,6 +705,8 @@ int docarp(void)
     int fd;
     int nfds;
     int iface_running = 1;
+    int poll_sleep_time;
+    struct timeval time_until_advert;
 
     sc.sc_vhid = vhid;
     sc.sc_advbase = advbase;
@@ -832,11 +846,23 @@ int docarp(void)
         break;
             }
         }
-    
-        nfds = poll(pfds, (nfds_t) 1, sc.sc_advbase * 1000);
+
+        if (sc.sc_ad_tmo.tv_sec == 0) {
+            poll_sleep_time = sc.sc_advbase * 1000;
+        } else {
+            if (gettimeofday(&now, NULL) != 0) {
+                logfile(LOG_WARNING, _("gettimeofday() failed: %s"),
+                        strerror(errno));
+                continue;
+            }
+            timersub(&sc.sc_ad_tmo, &now, &time_until_advert);
+            poll_sleep_time = (time_until_advert.tv_sec * 1000) +
+                (time_until_advert.tv_usec / 1000);
+        }
+        nfds = poll(pfds, (nfds_t) 1, MAX(1, poll_sleep_time));
         if (nfds == -1) {
             if (errno == EINTR) {
-                continue;
+               continue;
             }
             logfile(LOG_ERR, _("exiting: poll() error: %s"), strerror(errno));
         }
@@ -861,9 +887,18 @@ int docarp(void)
             carp_master_down(&sc);
         }
 #endif
-        if (sc.sc_ad_tmo.tv_sec != 0 && timercmp(&now, &sc.sc_ad_tmo, >)) {
-            carp_send_ad(&sc);
-        }
+        if (sc.sc_ad_tmo.tv_sec != 0) {
+           if (timercmp(&now, &sc.sc_ad_tmo, >)) {
+                carp_send_ad(&sc);
+           } else {
+               timersub(&sc.sc_ad_tmo, &now, &time_until_advert);
+               int diff_ms = (time_until_advert.tv_sec * 1000) +
+                   (time_until_advert.tv_usec / 1000);
+               if (abs(diff_ms) <= 1) {
+                    carp_send_ad(&sc);
+               }
+           }
+       }
     }
     pcap_close(dev_desc);
     pcap_freecode(&bpfp);
