@@ -51,7 +51,7 @@ int fill_mac_address(void)
             logfile(LOG_ERR, _("Interface name too long"));
             return -1;
         }
-        strcpy(ifr.ifr_name, interface);                
+        strncpy(ifr.ifr_name, interface, sizeof ifr.ifr_name);
         if (ioctl(s, SIOCGIFHWADDR, &ifr) != 0) {
             logfile(LOG_ERR,
                     _("Unable to get hardware info about an interface: %s"),
@@ -130,17 +130,18 @@ int fill_mac_address(void)
             return -1;
         }        
         lifr = lifc.lifc_req;
-        while (--lifn.lifn_count > 0) {
+	for(;;) {
+	    if (lifn.lifn_count <= 0) {
+		logfile(LOG_ERR, _("Interface [%s] not found"), interface);
+		ALLOCA_FREE(lifrspace);
+		return -1;            		
+	    }
+	    lifn.lifn_count--;
             if (strcmp(lifr->lifr_name, interface) == 0) {
                 break;
             }	   
             lifr++;
         }
-        if (lifn.lifn_count <= 0) {
-            logfile(LOG_ERR, _("Interface [%s] not found"), interface);
-            ALLOCA_FREE(lifrspace);
-            return -1;            
-        }
         memcpy(&arpreq.arp_pa, &lifr->lifr_addr, sizeof arpreq.arp_pa);
         ALLOCA_FREE(lifrspace);
         if (ioctl(s, SIOCGARP, &arpreq) != 0) {
