@@ -20,12 +20,16 @@ int spawn_handler(const int dev_desc_fd, const char * const script)
     pid = fork();
     if (pid == (pid_t) 0) {
         (void) close(dev_desc_fd);
-        execl(script, script, interface, vaddr_arg, xparam, (char *) NULL);
-	logfile(LOG_ERR, _("Unable to exec %s %s: %s"), script, interface,
-		strerror(errno));
+	execl(script, script, interface, vaddr_arg, xparam, (char *) NULL);
+	logfile(LOG_ERR, _("Unable to exec %s %s %s%s%s: %s"), 
+		script, interface, vaddr_arg, 
+                (xparam ? " " : ""), (xparam ? xparam : ""), 
+                strerror(errno));
         _exit(EXIT_FAILURE);
     } else if (pid != (pid_t) -1) {
-        logfile(LOG_WARNING, _("Spawning [%s %s]"), script, interface);
+        logfile(LOG_WARNING, _("Spawning [%s %s %s%s%s]"), 
+                script, interface, vaddr_arg, 
+                (xparam ? " " : ""), (xparam ? xparam : ""));
 #ifdef HAVE_WAITPID
 	{
 	    while (waitpid(pid, NULL, 0) == (pid_t) -1 && errno == EINTR);
