@@ -167,6 +167,10 @@ extern int errno;
 
 #define CAPTURE_TIMEOUT 1000
 
+#ifndef MAX
+#define MAX(a, b) ((a) < (b) ? (b) : (a))
+#endif
+
 struct carp_softc {
     int if_flags;                       /* current flags to treat UP/DOWN */
     struct ifnet *sc_ifp;
